Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(393)

Unified Diff: third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js

Issue 2493373002: DevTools: rename WebInspector into modules. (Closed)
Patch Set: for bots Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js
diff --git a/third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js b/third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js
index ed953c6aa5afcd462499d888f135f87bfe2ee819..82a1370404b950fc7753b448af0055aca863480e 100644
--- a/third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js
+++ b/third_party/WebKit/Source/devtools/front_end/audits/AuditCategory.js
@@ -28,9 +28,9 @@
/**
* @interface
*/
-WebInspector.AuditCategory = function() {};
+Audits.AuditCategory = function() {};
-WebInspector.AuditCategory.prototype = {
+Audits.AuditCategory.prototype = {
/**
* @return {string}
*/
@@ -42,10 +42,10 @@ WebInspector.AuditCategory.prototype = {
get displayName() {},
/**
* @param {!WebInspector.Target} target
* @param {!Array.<!WebInspector.NetworkRequest>} requests
* @param {function(!WebInspector.AuditRuleResult)} ruleResultCallback
* @param {!WebInspector.Progress} progress
*/
run: function(target, requests, ruleResultCallback, progress) {}
};
@@ -42,10 +42,10 @@ WebInspector.AuditCategory.prototype = {
get displayName() {},
/**
- * @param {!WebInspector.Target} target
- * @param {!Array.<!WebInspector.NetworkRequest>} requests
- * @param {function(!WebInspector.AuditRuleResult)} ruleResultCallback
- * @param {!WebInspector.Progress} progress
+ * @param {!SDK.Target} target
+ * @param {!Array.<!SDK.NetworkRequest>} requests
+ * @param {function(!Audits.AuditRuleResult)} ruleResultCallback
+ * @param {!Common.Progress} progress
*/
run: function(target, requests, ruleResultCallback, progress) {}

Powered by Google App Engine
This is Rietveld 408576698